@@ -3,7 +3,7 @@
 # Author      : E.Taskesen
 # Contact     : erdogant@gmail.com
 # github      : https://github.com/erdogant/findpeaks
-# Licence     : See Licences
+# Licence     : See LICENSE
 # ----------------------------------------------------
 
 # import findpeaks
@@ -18,9 +18,11 @@ import os
 import requests
 from urllib.parse import urlparse
 
+# #### DEBUG ONLY ####
 # import stats as stats
 # from stats import disable_tqdm
 # import interpolate as interpolate
+# #####################
 
 import findpeaks.stats as stats
 from findpeaks.stats import disable_tqdm
@@ -34,8 +36,9 @@ class findpeaks():
     Description
     -----------
     findpeaks is for the detection and vizualization of peaks and valleys in a 1D-vector and 2D-array.
-    In case of 2D-array, the image can be pre-processed by resizing, scaling, and denoising. For a 1D-vector, pre-processing by interpolation is possible.
-    Peaks can be detected using various methods, and the results can be vizualized, such as the preprocessing steps, the persistence of peaks, the masking plot and a 3d-mesh plot.
+    In case of 2D-array, the image can be pre-processed by resizing, scaling, and denoising. For a 1D-vector,
+    pre-processing by interpolation is possible. Peaks can be detected using various methods, and the results can be
+    vizualized, such as the preprocessing steps, the persistence of peaks, the masking plot and a 3d-mesh plot.
 
     Parameters
     ----------
@@ -126,9 +129,8 @@ class findpeaks():
 
     """
 
-    def __init__(self, method=None, whitelist=['peak','valley'], lookahead=200, interpolate=None, limit=None, imsize=None, scale=True, togray=True, denoise='fastnl', window=3, cu=0.25, params_caerus={'window': 50, 'minperc': 3, 'nlargest': 10, 'threshold': 0.25}, figsize=(15, 8), verbose=3):
+    def __init__(self, method=None, whitelist=['peak', 'valley'], lookahead=200, interpolate=None, limit=None, imsize=None, scale=True, togray=True, denoise='fastnl', window=3, cu=0.25, params_caerus={'window': 50, 'minperc': 3, 'nlargest': 10, 'threshold': 0.25}, figsize=(15, 8), verbose=3):
         """Initialize findpeaks parameters."""
-
         # Store in object
         if isinstance(whitelist, str): whitelist=[whitelist]
         if lookahead is None: lookahead=1
@@ -150,7 +152,7 @@ class findpeaks():
 
         # Store parameters for caerus
         caerus_defaults = {'window': 50, 'minperc': 3, 'nlargest': 10, 'threshold': 0.25}
-        params_caerus   = {**caerus_defaults, **params_caerus}
+        params_caerus = {**caerus_defaults, **params_caerus}
         self.params_caerus = params_caerus
 
     def fit(self, X, x=None):
@@ -404,7 +406,7 @@ class findpeaks():
             * method : method to be used for peak detection: 'topology', or 'mask'
             * limit : Values > limit are set as regions of interest (ROI).
             * scale : Scaling data in range [0-255] by img*(255/max(img))
-            * denoise : Remove noise using method: 
+            * denoise : Remove noise using method:
                 * None
                 * 'fastnl'
                 * 'bilateral'
@@ -595,7 +597,7 @@ class findpeaks():
         return X
 
     # %% Plotting
-    def plot(self, legend=True, figsize=None, cmap=None, text=True):
+    def plot(self, legend=True, figsize=None, cmap=None, text=True, xlabel='x-axis', ylabel='y-axis'):
         """Plot results.
 
         Parameters
@@ -621,7 +623,7 @@ class findpeaks():
         figsize = figsize if figsize is not None else self.args['figsize']
 
         if self.args['type']=='peaks1d':
-            fig_axis = self.plot1d(legend=legend, figsize=figsize)
+            fig_axis = self.plot1d(legend=legend, figsize=figsize, xlabel=xlabel, ylabel=ylabel)
         elif self.args['type']=='peaks2d':
             # fig_axis = self.plot2d(figsize=figsize)
             fig_axis = self.plot_mask(figsize=figsize, cmap=cmap, text=text)
@@ -632,7 +634,7 @@ class findpeaks():
         # Return
         return fig_axis
 
-    def plot1d(self, legend=True, figsize=None):
+    def plot1d(self, legend=True, figsize=None, xlabel='x-axis', ylabel='y-axis'):
         """Plot the 1D results.
 
         Parameters
@@ -659,22 +661,28 @@ class findpeaks():
             self.results['model']
             if self.results.get('model', None) is not None:
                 ax = self.results['model'].plot()
-                csplots._plot_graph(self.results['model'].results, figsize=self.figsize)
+                csplots._plot_graph(self.results['model'].results, figsize=self.figsize, xlabel=xlabel, ylabel=ylabel)
                 # Return axis
                 return ax
         else:
             # Make plot
+            min_peaks, max_peaks = np.array([]), np.array([])
             df = self.results['df']
-            min_peaks = df['x'].loc[df['valley']].values
-            max_peaks = df['x'].loc[df['peak']].values
-            ax1 = _plot_original(df['y'].values, df['x'].values, df['labx'].values, min_peaks.astype(int), max_peaks.astype(int), title=title, figsize=figsize, legend=legend)
+            if np.any('valley' in self.whitelist):
+                min_peaks = df['x'].loc[df['valley']].values
+            if np.any('peak' in self.whitelist):
+                max_peaks = df['x'].loc[df['peak']].values
+            ax1 = _plot_original(df['y'].values, df['x'].values, df['labx'].values, min_peaks.astype(int), max_peaks.astype(int), title=title, figsize=figsize, legend=legend, xlabel=xlabel, ylabel=ylabel)
 
             # Make interpolated plot
             if self.interpolate is not None:
+                min_peaks, max_peaks = np.array([]), np.array([])
                 df_interp = self.results['df_interp']
-                min_peaks = df_interp['x'].loc[df_interp['valley']].values
-                max_peaks = df_interp['x'].loc[df_interp['peak']].values
-                ax2 = _plot_original(df_interp['y'].values, df_interp['x'].values, df_interp['labx'].values, min_peaks.astype(int), max_peaks.astype(int), title=title + ' (interpolated)', figsize=figsize, legend=legend)
+                if np.any('valley' in self.whitelist):
+                    min_peaks = df_interp['x'].loc[df_interp['valley']].values
+                if np.any('peak' in self.whitelist):
+                    max_peaks = df_interp['x'].loc[df_interp['peak']].values
+                ax2 = _plot_original(df_interp['y'].values, df_interp['x'].values, df_interp['labx'].values, min_peaks.astype(int), max_peaks.astype(int), title=title + ' (interpolated)', figsize=figsize, legend=legend, xlabel=xlabel, ylabel=ylabel)
             # Return axis
             return (ax2, ax1)
 
@@ -708,7 +716,7 @@ class findpeaks():
 
         # Plot mesh
         ax_mesh = self.plot_mesh(figsize=figsize)
-        
+
         # Return axis
         return (ax_method, ax_mesh)
 
@@ -762,7 +770,7 @@ class findpeaks():
         # Setup figure
         figsize = figsize if figsize is not None else self.args['figsize']
         fig, (ax1, ax2, ax3) = plt.subplots(1, 3, figsize=figsize)
-        
+
         # Plot input image
         ax1.imshow(self.results['Xraw'], cmap, interpolation="nearest")
         ax1.set_title('Input')
@@ -780,16 +788,16 @@ class findpeaks():
         ax3.imshow(np.abs(Xdetect), 'gray_r', interpolation="nearest")
         ax3.set_title(self.method + ' (' + str(len(np.where(Xdetect>0)[0])) + ' peaks and ' + str(len(np.where(Xdetect<0)[0])) + ' valleys)')
         ax3.grid(False)
-        
+
         if text:
             for idx in tqdm(zip(idx_peaks[0], idx_peaks[1]), disable=disable_tqdm(self.verbose)):
-                ax2.text(idx[1], idx[0], 'p'+self.results['Xranked'][idx].astype(str))
-                ax3.text(idx[1], idx[0], 'p'+self.results['Xranked'][idx].astype(str))
-    
+                ax2.text(idx[1], idx[0], 'p' + self.results['Xranked'][idx].astype(str))
+                ax3.text(idx[1], idx[0], 'p' + self.results['Xranked'][idx].astype(str))
+
             for idx in tqdm(zip(idx_valleys[0], idx_valleys[1]), disable=disable_tqdm(self.verbose)):
-                ax2.text(idx[1], idx[0], 'v'+self.results['Xranked'][idx].astype(str))
-                ax3.text(idx[1], idx[0], 'v'+self.results['Xranked'][idx].astype(str))
-        
+                ax2.text(idx[1], idx[0], 'v' + self.results['Xranked'][idx].astype(str))
+                ax3.text(idx[1], idx[0], 'v' + self.results['Xranked'][idx].astype(str))
+
         # Show plot
         plt.show()
         # Return
@@ -895,13 +903,17 @@ class findpeaks():
         # plt.show()
         return ax1, ax2
 
-    def plot_persistence(self, figsize=(20, 8), verbose=None):
+    def plot_persistence(self, figsize=(20, 8), fontsize_ax1=14, fontsize_ax2=14, xlabel='x-axis', ylabel='y-axis', verbose=None):
         """Plot the homology-peristence.
 
         Parameters
         ----------
         figsize : (int, int), (default: None)
             (width, height) in inches.
+        fontsize_ax1 : int, (default: 14)
+            Font size for the labels in the left figure. Choose None for no text-labels.
+        fontsize_ax2 : int, (default: 14)
+            Font size for the labels in the right figure. Choose None for no text-labels.
         verbose : int (default : 3)
             Print to screen. 0: None, 1: Error, 2: Warning, 3: Info, 4: Debug, 5: Trace.
 
@@ -922,19 +934,37 @@ class findpeaks():
         figsize = figsize if figsize is not None else self.args['figsize']
         fig, (ax1, ax2) = plt.subplots(1, 2, figsize=figsize)
 
+        # Create the persistence ax2
+        ax2 = self._plot_persistence_ax2(fontsize_ax2, ax2, verbose)
+        # Create the persistence ax1
+        ax1, ax2 = self._plot_persistence_ax1(fontsize_ax1, ax1, ax2, figsize, xlabel, ylabel, verbose)
+        # Plot
+        plt.show()
+        # Return
+        return ax1, ax2
+
+    def _plot_persistence_ax1(self, fontsize, ax1, ax2, figsize, xlabel, ylabel, verbose):
         if self.args['type']=='peaks1d':
-            # minpers = 0
-            min_peaks = self.results['df']['x'].loc[self.results['df']['valley']].values
-            max_peaks = self.results['df']['x'].loc[self.results['df']['peak']].values
-            ax1 = _plot_original(self.results['df']['y'].values, self.results['df']['x'].values, self.results['df']['labx'].values, min_peaks.astype(int), max_peaks.astype(int), title='Persistence', figsize=figsize, legend=True, ax=ax1)
-
             # Attach the ranking-labels
-            y = self.results['df']['y'].values
-            x = self.results['df']['x'].values
-            idx = np.where(self.results['df']['rank']>0)[0]
-            for i in tqdm(idx, disable=disable_tqdm(verbose)):
-                ax1.text(x[i], (y[i] + y[i] * 0.01), str(self.results['df']['rank'].iloc[i]), color='b')
+            if fontsize is not None:
+                y = self.results['df']['y'].values
+                x = self.results['df']['x'].values
+                idx = np.where(self.results['df']['rank']>0)[0]
+                for i in tqdm(idx, disable=disable_tqdm(verbose)):
+                    ax1.text(x[i], (y[i] + y[i] * 0.01), str(self.results['df']['rank'].iloc[i]), color='b', fontsize=fontsize)
 
+            # minpers = 0
+            min_peaks, max_peaks = np.array([]), np.array([])
+            if np.any('valley' in self.whitelist):
+                min_peaks = self.results['df']['x'].loc[self.results['df']['valley']].values
+            if np.any('peak' in self.whitelist):
+                max_peaks = self.results['df']['x'].loc[self.results['df']['peak']].values
+            # Make the plot
+            ax1 = _plot_original(self.results['df']['y'].values, self.results['df']['x'].values, self.results['df']['labx'].values, min_peaks.astype(int), max_peaks.astype(int), title='Persistence', figsize=figsize, legend=True, ax=ax1, xlabel=xlabel, ylabel=ylabel)
+            # Set limits
+            X = np.c_[self.results['df']['x'].values, self.results['df']['y'].values]
+            ax1.set_xlim((np.min(X), np.max(X)))
+            ax1.set_ylim((np.min(X), np.max(X)))
         else:
             # X = self.results['Xproc']
             # Make the figure
@@ -950,42 +980,29 @@ class findpeaks():
                     y, x = p_birth
                     Xdetect[y, x] = i + 1
                     ax1.plot([x], [y], '.', c='b')
-                    ax1.text(x, y + 0.25, str(i), color='b')
+                    ax1.text(x, y + 0.25, str(i), color='b', fontsize=fontsize)
                 elif pers > self.limit:
                     y, x = p_birth
                     Xdetect[y, x] = i + 1
                     ax1.plot([x], [y], '.', c='b')
-                    ax1.text(x, y + 0.25, str(i), color='b')
+                    ax1.text(x, y + 0.25, str(i), color='b', fontsize=fontsize)
 
             ax1.set_xlim((0, self.results['Xproc'].shape[1]))
             ax1.set_ylim((0, self.results['Xproc'].shape[0]))
             ax1.invert_yaxis()
             plt.gca().invert_yaxis()
             ax1.grid(True)
+            # Set the axis to 255-255 in ax2 because it is an image.
             ax2.plot([0, 255], [0, 255], '-', c='grey')
+        return ax1, ax2
 
-        # Plot the persistence
+    def _plot_persistence_ax2(self, fontsize, ax2, verbose):
         x = self.results['persistence']['birth_level'].values
         y = self.results['persistence']['death_level'].values
-        plt.plot(x, y, '.', c='b')
-        for i in tqdm(range(0,len(x)), disable=disable_tqdm(verbose)):
-            plt.text(x[i], (y[i] + y[i] * 0.01),  str(i + 1), color='b')
-
-        # if verbose>=3: print('[findpeaks] >Plotting Peristence..')
-        # ax2.set_title("Peristence diagram")
-        # xcoord = []
-        # ycoord = []
-        # perssc = []
-        # for i, homclass in tqdm(enumerate(self.results['groups0'])):
-        #     p_birth, bl, pers, p_death = homclass
-        #     if pers > minpers:
-        #         x, y = bl, (bl - pers)
-        #         xcoord.append(x)
-        #         ycoord.append(y)
-        #         perssc.append(pers)
-        #         ax2.plot([x], [y], '.', c='b')
-        #         ax2.text(x, (y + y * 0.01), str(i + 1), color='b')
-        # X = xcoord + ycoord
+        ax2.plot(x, y, '.', c='b')
+        if fontsize is not None:
+            for i in tqdm(range(0, len(x)), disable=disable_tqdm(verbose)):
+                ax2.text(x[i], (y[i] + y[i] * 0.01), str(i + 1), color='b', fontsize=fontsize)
 
         X = np.c_[x, y]
         ax2.plot([np.min(X), np.max(X)], [np.min(X), np.max(X)], '-', c='grey')
@@ -994,8 +1011,7 @@ class findpeaks():
         ax2.set_xlim((np.min(X), np.max(X)))
         ax2.set_ylim((np.min(X), np.max(X)))
         ax2.grid(True)
-        plt.show()
-        return ax1, ax2
+        return ax2
 
     def import_example(self, data='2dpeaks', url=None, sep=';', datadir=None):
         """Import example dataset from github source.
@@ -1027,14 +1043,16 @@ class findpeaks():
 
 
 # %%
-def _plot_original(X, xs, labx, min_peaks, max_peaks, title=None, legend=True, ax=None, figsize=(15, 8)):
+def _plot_original(X, xs, labx, min_peaks, max_peaks, title=None, legend=True, ax=None, figsize=(15, 8), xlabel=None, ylabel=None):
     uilabx = np.unique(labx)
     uilabx = uilabx[~np.isnan(uilabx)]
 
     if ax is None: fig, ax = plt.subplots(figsize=figsize)
     ax.plot(xs, X, 'k')
-    ax.plot(max_peaks, X[max_peaks], "x", label='Top')
-    ax.plot(min_peaks, X[min_peaks], "o", label='Bottom')
+    if np.any(max_peaks):
+        ax.plot(max_peaks, X[max_peaks], "x", label='Peak')
+    if np.any(min_peaks):
+        ax.plot(min_peaks, X[min_peaks], "o", label='Valley')
 
     # Color each detected label
     s=np.arange(0, len(X))
@@ -1045,6 +1063,8 @@ def _plot_original(X, xs, labx, min_peaks, max_peaks, title=None, legend=True, a
 
     if legend: ax.legend(loc=0)
     ax.set_title(title)
+    if xlabel is not None: ax.set_xlabel(xlabel)
+    if ylabel is not None: ax.set_ylabel(ylabel)
     ax.grid(True)
     plt.show()
     return ax
@@ -1090,7 +1110,7 @@ def import_example(data='2dpeaks', url=None, sep=';', verbose=3, datadir=None):
         fn = "2dpeaks.zip"
     elif data=='1dpeaks':
         # x = [0,   13,  22,  30,  35,  38,   42,   51,   57,   67,  73,   75,  89,   126,  141,  150,  200 ]
-        y = [1.5, 0.8, 1.2, 0.2, 0.4, 0.39, 0.42, 0.22, 0.23, 0.1, 0.11, 0.1, 0.14, 0.09, 0.04,  0.02, 0.01]
+        y = [1.5, 0.8, 1.2, 0.2, 0.4, 0.39, 0.42, 0.22, 0.23, 0.1, 0.11, 0.1, 0.14, 0.09, 0.04, 0.02, 0.01]
         # X = np.c_[x, y]
         return y
     elif (data=='btc') or (data=='facebook'):
